@@ -1,6 +1,6 @@
 from blues_lib.type.output.STDOut import STDOut
 from blues_lib.type.executor.Behavior import Behavior
-from blues_lib.behavior.hook.BhvHook import BhvHook
+from blues_lib.hook.behavior.BehaviorHook import BehaviorHook
 
 class Bean(Behavior):
 
@@ -11,7 +11,7 @@ class Bean(Behavior):
         value = self._set()
       else:
         value = self._get()
-        value = self._after_get(value)
+        value = self._after_got(value)
       return STDOut(200,'ok',value)
     except Exception as e:
       return STDOut(500,str(e),value)
@@ -30,14 +30,12 @@ class Bean(Behavior):
       action = 'setter'
     return action
   
-  def _after_get(self,value:any)->any:
+  def _after_got(self,value:any)->any:
     # 在getter后调用，用于处理获取到的值
-    hook_value = self._config.get('after_get')
-    if not hook_value:
-      return value
-
-    proc_confs:list[dict] = hook_value if isinstance(hook_value,list) else [hook_value]
-    return BhvHook(value,proc_confs,self._model).execute()
+    hook_defs:list[dict[str,any]] = self._config.get('after_got')
+    options = {'value':value}
+    BehaviorHook(hook_defs,options).execute()
+    return options.get('value')
   
   def _get_value_entity(self)->dict|None:
 
