@@ -1,10 +1,7 @@
-import sys,os,re
-
 from blues_lib.command.NodeCommand import NodeCommand
 from blues_lib.type.output.STDOut import STDOut
 from blues_lib.sele.browser.chrome.ChromeFactory import ChromeFactory   
 from blues_lib.namespace.CommandName import CommandName
-from blues_lib.config.ConfigManager import config
 
 class Creator(NodeCommand):
 
@@ -12,8 +9,7 @@ class Creator(NodeCommand):
   TYPE = CommandName.Type.ACTION
 
   def _invoke(self)->STDOut:
-    mode =  self._node_conf.get('mode')
-    headless =  self._node_conf.get('headless') or False
-    kwargs = self._node_conf.get('kwargs') or {}
-    browser = ChromeFactory(**kwargs).create(mode,headless)
+    driver_config =  self._summary.get('driver_config')
+    driver_options = self._summary.get('driver_options') or {}
+    browser = ChromeFactory(**driver_options).create(driver_config)
     return STDOut(200,'ok',browser) if browser else STDOut(500,'failed to create the browser')
\ No newline at end of file
