@@ -7,14 +7,14 @@ from blues_lib.namespace.CommandName import CommandName
 class Engine(NodeCommand):
 
   NAME = CommandName.Flow.ENGINE
-  TYPE = CommandName.Type.SETTER
+  
   
 
   def _invoke(self)->STDOut:
     # lazy to import to avoid circular import
     from blues_lib.flow.FlowFactory import FlowFactory
     
-    queue_maps:list[dict] = self._node_input
+    queue_maps:list[dict] = self._model
     sub_flow = FlowFactory(queue_maps).create()
     # 保留一个对父flow context的引用，用于取值
     sub_flow.context[CommandName.IO.PARENT.value] = self._context
