@@ -7,7 +7,7 @@ from blues_lib.namespace.CommandName import CommandName
 class Queue(NodeCommand):
 
   NAME = CommandName.Flow.QUEUE
-  TYPE = CommandName.Type.SETTER
+  
   
 
   def _invoke(self):
@@ -15,7 +15,7 @@ class Queue(NodeCommand):
     from blues_lib.flow.FlowFactory import FlowFactory
     prev_output:STDOut = None
 
-    for context in self._node_input:
+    for context in self._model:
       # append prev output to current flow
       if prev_output:
         context[CommandName.IO.OUTPUT.value] = prev_output
