@@ -1,11 +1,8 @@
-import sys,os,re
-
 from blues_lib.type.chain.AllMatchHandler import AllMatchHandler
 from blues_lib.type.output.STDOut import STDOut
-from blues_lib.material.formatter.Normalizer import Normalizer
-from blues_lib.material.formatter.Validator import Validator
-from blues_lib.material.formatter.Deduplicator import Deduplicator
-from blues_lib.material.privatizer.Localizer import Localizer
+from blues_lib.material.deduplicator.Deduplicator import Deduplicator
+from blues_lib.material.validator.Validator import Validator
+from blues_lib.material.normalizer.Normalizer import Normalizer
 from blues_lib.material.sinker.Sinker import Sinker
 
 class MatHanderChain(AllMatchHandler):
@@ -25,11 +22,10 @@ class MatHanderChain(AllMatchHandler):
       return STDOut(500,message)
   
   def _get_chain(self)->AllMatchHandler:
-    normalizer = Normalizer(self._request)
     deduplicator = Deduplicator(self._request)
     validator = Validator(self._request)
-    localizer = Localizer(self._request)
+    normalizer = Normalizer(self._request)
     sinker = Sinker(self._request)
     
-    normalizer.set_next(deduplicator).set_next(validator).set_next(localizer).set_next(sinker)
-    return normalizer
+    deduplicator.set_next(validator).set_next(normalizer).set_next(sinker)
+    return deduplicator
