@@ -1,5 +1,3 @@
-import sys,os,re
-
 from blues_lib.material.MatHandler import MatHandler
 from blues_lib.type.output.STDOut import STDOut
 from blues_lib.material.privatizer.image.Downloader import Downloader
@@ -9,26 +7,21 @@ class Localizer(MatHandler):
 
   def resolve(self)->STDOut:
     self._setup()
-    config = self._config.get('privatizer')
-    if not config:
-      return STDOut(200,'no privatizer config')
+
+    if not self._entities:
+      return STDOut(400,f'{self.__class__.__name__} entities is empty')
 
     avail_entities = []
     for entity in self._entities:
       request = {
+        'rule':self._rule,
         'entity':entity,
-        'config':config,
       }
       if self._handle(request):
         avail_entities.append(entity)
-      else:
-        # mark the invalid mat to the DB
-        self._mark(entity)
     
-    self._request['entities'] = avail_entities
-    stdout = STDOut(200,'ok',avail_entities) if avail_entities else STDOut(500,'all are unlocalized')
-    self._log(stdout)
-    return stdout
+    output= STDOut(200,'ok',avail_entities) if avail_entities else STDOut(500,'all are unlocalized')
+    return output
 
   def _handle(self,request:dict)->bool:
     try:
@@ -38,5 +31,9 @@ class Localizer(MatHandler):
       downloader.handle()
       return True
     except Exception as e:
+      # must update the stats
+      request['entity']['mat_stat'] = 'invalid'
+      request['entity']['mat_remark'] = str(e)
+      
       self._logger.warning(f'localize error: {e}')
       return False
