@@ -13,7 +13,7 @@ class ChromeArgsFactory:
     self.__sel_args = sel_args or {}
     self.__ext_args = ext_args or {}
 
-  def create(self):
+  def create(self)->dict:
     std_args = ChromeStdArgs(self.__std_args).get()
     exp_args = ChromeExpArgs(self.__exp_args).get()
     cdp_args = ChromeCDPArgs(self.__cdp_args).get()
@@ -24,7 +24,6 @@ class ChromeArgsFactory:
     if sel_args.get('debugger_address'):
       std_args = None # has no effect
       exp_args = None # must remove
-
     return {
       'std':std_args,
       'exp':exp_args,
@@ -33,9 +32,8 @@ class ChromeArgsFactory:
       'ext':ext_args,
     }
 
-  def create_udc(self):
-    # 追加少量默认配置
-    self.__std_args.append('--disable-infobars')
+  def format(self)->dict:
+    # 只返回结构，不设置任何默认配置
     return {
       'std':self.__std_args,
       'exp':self.__exp_args,
