@@ -1,9 +1,7 @@
-from typing import Any
-
 class NestedDataReader:
   
   @staticmethod
-  def read_by_path(data: Any, path: str) -> Any:
+  def read_by_path(data: any, path: str) -> any:
     """
     根据路径字符串获取数据中对应节点的值
     
@@ -19,7 +17,7 @@ class NestedDataReader:
     
     # 拆分路径为各个部分
     parts = path.split('.')
-    current: Any = data
+    current: any = data
     
     for part in parts:
       # 处理列表类型
